import Card from "@components/common/card";
import Layout from "@components/layouts/admin";
import Search from "@components/common/search";
import ProductList from "@components/product/product-list";
import ErrorMessage from "@components/ui/error-message";
import Loader from "@components/ui/loader/loader";
import { SortOrder } from "@graphql/attributes.graphql";
import {
  QueryProductsHasCategoriesColumn,
  QueryProductsHasTypeColumn,
  QueryProductsOrderByColumn,
  useProductsQuery,
} from "@graphql/products.graphql";
import { useCallback, useState } from "react";
import { useTranslation } from "next-i18next";
import { serverSideTranslations } from "next-i18next/serverSideTranslations";
import { adminOnly } from "@utils/auth-utils";
import CategoryTypeFilter from "@components/product/category-type-filter";
import SortFormGql from "@components/common/sort-form-gql";
import cn from "classnames";
import { ArrowDown } from "@components/icons/arrow-down";
import { ArrowUp } from "@components/icons/arrow-up";

export default function ProductsPage() {
  const { t } = useTranslation();
  const [searchTerm, setSearchTerm] = useState("");
  const [visible, setVisible] = useState(false);

  const toggleVisible = () => {
    setVisible((v) => !v);
  };

  const { data, loading, error, refetch } = useProductsQuery({
    variables: {
      first: 10,
      orderBy: [
        {
          column: QueryProductsOrderByColumn.CreatedAt,
          order: SortOrder.Desc,
        },
      ],
      page: 1,
    },
    fetchPolicy: "network-only",
  });

  if (loading) return <Loader text={t("common:text-loading")} />;
  if (error) return <ErrorMessage message={error.message} />;

  function handleSearch({ searchText }: { searchText: string }) {
    setSearchTerm(searchText);
    refetch({
      text: `%${searchText}%`,
      page: 1,
    });
  }
  function handlePagination(current: any) {
    refetch({
      text: `%${searchTerm}%`,
      page: current,
    });
  }
  return (
    <>
      <Card className="flex flex-col mb-8">
        <div className="w-full flex flex-col md:flex-row items-center">
          <div className="md:w-1/4 mb-4 md:mb-0">
            <h1 className="text-lg font-semibold text-heading">
              {t("form:input-label-products")}
            </h1>
          </div>

          <div className="w-full md:w-3/4 flex flex-col items-center ms-auto">
            <Search onSearch={handleSearch} />
          </div>

          <button
            className="text-accent text-base font-semibold flex items-center md:ms-5 mt-5 md:mt-0"
            onClick={toggleVisible}
          >
            {t("common:text-filter")}{" "}
            {visible ? (
              <ArrowUp className="ms-2" />
            ) : (
              <ArrowDown className="ms-2" />
            )}
          </button>
        </div>

        <div
          className={cn("w-full flex transition", {
            "h-auto visible": visible,
            "h-0 invisible": !visible,
          })}
        >
          <div className="flex flex-col md:flex-row md:items-center mt-5 md:mt-8 border-t border-gray-200 pt-5 md:pt-8 w-full">
            <CategoryTypeFilter
              refetch={refetch}
              className="w-full md:w-2/3 md:mr-5"
            />

            <SortFormGql
              className="w-full md:w-1/3 mt-5 md:mt-0"
              refetch={refetch}
              options={Object.values(QueryProductsOrderByColumn).map(
                (value) => ({
                  label: value,
                  value: value,
                })
              )}
            />
          </div>
        </div>
      </Card>

      {/* <Card className="flex flex-col md:flex-row items-center mt-8 w-full mb-8 space-x-5">
        <CategoryTypeFilter refetch={refetch} className="w-1/2" />

        <SortFormGql
          className="w-1/2"
          refetch={refetch}
          options={Object.values(QueryProductsOrderByColumn).map((value) => ({
            label: value,
            value: value,
          }))}
        />
      </Card> */}

      <ProductList products={data?.products} onPagination={handlePagination} />
    </>
  );
}
ProductsPage.authenticate = {
  permissions: adminOnly,
};
ProductsPage.Layout = Layout;

export const getStaticProps = async ({ locale }: any) => ({
  props: {
    ...(await serverSideTranslations(locale, ["table", "common", "form"])),
  },
});
